require 'spec_helper'

describe RubyUber::V1::Products do

  let(:client) {
    RubyUber::Client.new({
      server_token: 'my_great_token',
      client_id: 'my_client_id',
      secret: 'shhh'
    })
  }

  let(:query) {
    {
      latitude: URBAN_FUTURE_LAB_COORDINATES[:latitude],
      longitude: URBAN_FUTURE_LAB_COORDINATES[:longitude]
    }
  }

  it "queries the /products endpoint" do

    stub_request(:get, /api.uber.com\/v1\/products/).
      to_return(body: PRODUCTS_RESPONSE)

    result = RubyUber::V1::Products.new(client: client).get(query)

    expect(WebMock).to have_requested(:get, "https://api.uber.com/v1/products").
      with(query: query, :headers => {'Authorization' => 'Token my_great_token'})

  end

  it "gets details available products" do
    stub_request(:get, /api.uber.com\/v1\/products/).
      to_return(body: PRODUCTS_RESPONSE) unless live?

    result = RubyUber::V1::Products.new(client: live_client { client }).get(query)

    expect(result).to be_a(Array)
    expect(result.first[:product_id]).to be_a(String)
    expect(result.first[:display_name]).to be_a(String)
    expect(result.first[:image]).to match(/^http/)
  end

end
