require 'spec_helper'

describe RubyUber::V1::TimeEstimates do

  let(:client) {
    RubyUber::Client.new({
      server_token: 'my_great_token',
      client_id: 'my_client_id',
      secret: 'shhh'
    })
  }

  let(:query) {
    {
      start_latitude: URBAN_FUTURE_LAB_COORDINATES[:latitude],
      start_longitude: URBAN_FUTURE_LAB_COORDINATES[:longitude]
    }
  }

  it "queries the /estimates/time endpoint" do
    stub_request(:get, /api.uber.com\/v1\/estimates\/time/).
      to_return(body: TIME_ESTIMATES_RESPONSE)

    result = RubyUber::V1::TimeEstimates.new(client: client).get(query)

    expect(WebMock).to have_requested(:get, "https://api.uber.com/v1/estimates/time").
      with(query: query, headers: {'Authorization'=>'Token my_great_token'})
  end

  it "gets time information for available products" do
    stub_request(:get, /api.uber.com\/v1\/estimates\/time/).
      to_return(body: TIME_ESTIMATES_RESPONSE) unless live?

    result = RubyUber::V1::TimeEstimates.new(client: live_client { client }).get(query)

    expect(result).to be_a(Array)
    expect(result.first[:product_id]).to be_a(String)
    expect(result.first[:estimate]).to be_a(Fixnum)
  end

end